summaryrefslogtreecommitdiffstats
path: root/ash/shelf/shelf_window_watcher.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-02-03 23:51:27 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-02-03 23:51:27 +0000
commiteec097142c4b7d09ff01a03e2e2117f290d68cfc (patch)
treee31de7ef3985e92eabbfb65ed10dac797c0ba0b6 /ash/shelf/shelf_window_watcher.h
parent3b3af9753ec5dd2796df0555900515bb8ba0c613 (diff)
downloadchromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.zip
chromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.tar.gz
chromium_src-eec097142c4b7d09ff01a03e2e2117f290d68cfc.tar.bz2
Renames LauncherID, LauncherItem and LauncherItems...
to ShelfID, ShelfItem and ShelfItems. BUG=248353 TEST=None R=jamescook@chromium.org,harrym@chromium.org Review URL: https://codereview.chromium.org/152223002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@248619 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shelf/shelf_window_watcher.h')
-rw-r--r--ash/shelf/shelf_window_watcher.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/ash/shelf/shelf_window_watcher.h b/ash/shelf/shelf_window_watcher.h
index e69138f..57b4ed2 100644
--- a/ash/shelf/shelf_window_watcher.h
+++ b/ash/shelf/shelf_window_watcher.h
@@ -30,7 +30,7 @@ class ShelfModel;
class ShelfItemDelegateManager;
namespace internal {
-// ShelfWindowWatcher creates and handles a LauncherItem for windows that have
+// ShelfWindowWatcher creates and handles a ShelfItem for windows that have
// a ShelfItemDetails property in the default container.
class ShelfWindowWatcher : public aura::client::ActivationChangeObserver,
public aura::WindowObserver,
@@ -75,11 +75,11 @@ class ShelfWindowWatcher : public aura::client::ActivationChangeObserver,
DISALLOW_COPY_AND_ASSIGN(RemovedWindowObserver);
};
- // Creates a LauncherItem for |window| that has ShelfItemDetails.
- void AddLauncherItem(aura::Window* window);
+ // Creates a ShelfItem for |window| that has ShelfItemDetails.
+ void AddShelfItem(aura::Window* window);
- // Removes a LauncherItem for |window|.
- void RemoveLauncherItem(aura::Window* window);
+ // Removes a ShelfItem for |window|.
+ void RemoveShelfItem(aura::Window* window);
// Adds observer to default container and ActivationClient of |root_window|.
void OnRootWindowAdded(aura::Window* root_window);
@@ -90,8 +90,8 @@ class ShelfWindowWatcher : public aura::client::ActivationChangeObserver,
// Updates the status of ShelfItem for |window|.
void UpdateShelfItemStatus(aura::Window* window, bool is_active);
- // Returns the index of LauncherItem associated with |window|.
- int GetLauncherItemIndexForWindow(aura::Window* window) const;
+ // Returns the index of ShelfItem associated with |window|.
+ int GetShelfItemIndexForWindow(aura::Window* window) const;
// Used when a window is removed. During the dragging a window may be removed
// and when the drag completes added back. When this happens we don't want to